@@ -639,6 +639,8 @@ function LinearAlgebra.svd!(
     # To avoid breaking on <Julia 1.3, the `alg` keyword doesn't do anything. Once we drop support for Julia 1.2
     # and below, we can make the keyword argument work correctly
     alg = nothing,
+    atol = 0,
+    rtol = 0
 ) where {T}
 
     m, n = size(A)
@@ -660,6 +662,13 @@ function LinearAlgebra.svd!(
     rmul!(Vᴴ, BF.rightQ')
 
     s = F.S
+    s[_count_svdvals(s, atol, rtol)+1:end] .= 0
 
     return SVD(U, s, Vᴴ)
 end
+
+function _count_svdvals(S, atol::Real, rtol::Real)
+    isempty(S) && return 0
+    tol = max(rtol * S[1], atol)
+    return iszero(S[1]) ? 0 : searchsortedlast(S, tol, rev=true)
+end
